@@ -1065,6 +1065,6 @@ def _subtract(start, stop, intervals):
     
 
 import sys
-from .integration import integrate
+from petlx.integration import integrate
 integrate(sys.modules[__name__])
 
