@@ -66,6 +66,6 @@ def displayall(tbl, **kwargs):
 
 
 import sys
-from .integration import integrate
+from petlx.integration import integrate
 integrate(sys.modules[__name__])
 
