@@ -304,5 +304,5 @@ def unpackcall(tbl, *keys, **kwargs):
     
       
 import sys    
-from .integration import integrate
+from petlx.integration import integrate
 integrate(sys.modules[__name__])
